pub fn from_python<T: FromPython>(obj: Py<PyAny>) -> PyResult<T>Expand description
Helper function to convert Python object to Rust value
pub fn from_python<T: FromPython>(obj: Py<PyAny>) -> PyResult<T>Helper function to convert Python object to Rust value