Module macro_embed

Module macro_embed 

Functions

exec_python_code
Execute Python code without returning a value
run_python_code
Execute Python code as a string and return the result This is the runtime function called by the python! macro