run_python_code

Function run_python_code 

pub fn run_python_code<T>(
    code: &str,
    locals: Option<HashMap<String, Py<PyAny>>>,
) -> Result<T>
where T: for<'py> FromPyObject<'py>,
Execute Python code as a string and return the result This is the runtime function called by the python! macro