pub fn run_python_code<T>(
code: &str,
locals: Option<HashMap<String, Py<PyAny>>>,
) -> Result<T>where
T: for<'py> FromPyObject<'py>,Expand description
Execute Python code as a string and return the result This is the runtime function called by the python! macro